summaryrefslogtreecommitdiff
path: root/inc/storage.h
diff options
context:
space:
mode:
Diffstat (limited to 'inc/storage.h')
-rw-r--r--inc/storage.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/inc/storage.h b/inc/storage.h
index 9707041..793b982 100644
--- a/inc/storage.h
+++ b/inc/storage.h
@@ -73,10 +73,10 @@ class Storage
*/
int wait_time;
/**
* A flag indicating whether this level of storage is currently blocked by a
* lower level.
*/
- int is_blocked;
+ int is_waiting;
};
#endif /* STORAGE_H_INCLUDED */
@@ -73,10 +73,10 @@ class Storage
int wait_time;
/**
- * A flag indicating whether this level of storage is currently blocked by a
- * lower level.
+ * A flag indicating whether this level of storage is currently waiting for
+ * a lower level.
*/